==> breezypythongui-1.1.1.tar.gz: breezypythongui-1.1.1/README.md <==
## BreezyPythonGUI (Unofficial Pip Distribution)

This project is an unofficial distribution of the BreezyPythonGUI library, created to allow for easier installation via pip. BreezyPythonGUI is a powerful tool for simplifying graphical user interface (GUI) development in Python.

**Original Author:**

* Ken Lambert (Washington and Lee University)

**Description:**

BreezyPythonGUI provides a higher-level abstraction over Python's built-in tkinter library, making GUI development more accessible. It offers classes for common UI elements like buttons, labels, text boxes, and menus, along with simplified event handling for user interactions.

**Installation:**

While the official BreezyPythonGUI is not available on the Python Package Index (PyPI), you can install this distribution using pip:

```bash
pip install breezypythongui
```

**Important Note:**

This repository is not affiliated with the official BreezyPythonGUI project. It is intended to provide a convenient way to install the library for educational purposes. Please refer to the official website for the latest information and documentation: [breezypythongui ON Kenneth Lambert lambertk.academic.wlu.edu]

**Feedback:**

For feedback on the original BreezyPythonGUI library, please contact Ken Lambert at lambertk@wlu.edu.

**License:**

The license for this distribution is the same as the original BreezyPythonGUI library. Please consult the official documentation for details.

**Disclaimer:**

This project is provided for educational purposes only. The authors of this repository are not responsible for any issues arising from its use.

==> breezypythongui-1.1.2.tar.gz: breezypythongui-1.1.2/README.md <==
## BreezyPythonGUI (Unofficial Pip Distribution)

This project is an unofficial distribution of the BreezyPythonGUI library, created to allow for easier installation via pip. BreezyPythonGUI is a powerful tool for simplifying graphical user interface (GUI) development in Python.

**Original Author:**

* Ken Lambert (Washington and Lee University)

**Description:**

BreezyPythonGUI provides a higher-level abstraction over Python's built-in tkinter library, making GUI development more accessible. It offers classes for common UI elements like buttons, labels, text boxes, and menus, along with simplified event handling for user interactions.

**Installation:**

While the official BreezyPythonGUI is not available on the Python Package Index (PyPI), you can install this distribution using pip:

```bash
pip install breezypythongui
```

**Important Note:**

This repository is not affiliated with the official BreezyPythonGUI project. It is intended to provide a convenient way to install the library for educational purposes. Please refer to the official website for the latest information and documentation: [BreezyPythonGUI](https://lambertk.academic.wlu.edu/breezypythongui/)

**Feedback:**

For feedback on the original BreezyPythonGUI library, please contact Ken Lambert at lambertk@wlu.edu.

**License:**

The license for this distribution is the same as the original BreezyPythonGUI library. Please consult the official documentation for details.

**Disclaimer:**

This project is provided for educational purposes only. The authors of this repository are not responsible for any issues arising from its use.
